# Generated by Django 2.0rc1 on 2017-11-29 09:39

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0002_openidclient_keys'),
    ]

    operations = [
        migrations.CreateModel(
            name='OpenIDKey',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key_type', models.CharField(choices=[('jwk_rsa_private', 'JWK RSA private key'), ('jwk_rsa_public', 'JWK RSA public key'), ('aes', 'AES key')], max_length=16)),
                ('encrypted_key_value', models.BinaryField()),
            ],
        ),
        migrations.RemoveField(
            model_name='openidclient',
            name='keys',
        ),
        migrations.AddField(
            model_name='openidkey',
            name='client',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='openid_connect_op.OpenIDClient'),
        ),
    ]
