# Generated by Django 2.0rc1 on 2017-11-29 08:58

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='openidclient',
            name='keys',
            field=jsonfield.fields.JSONField(default={}),
        ),
    ]
