# Generated by Django 2.0rc1 on 2017-11-30 09:56

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0003_auto_20171129_0339'),
    ]

    operations = [
        migrations.AddField(
            model_name='openidclient',
            name='allowed_claims',
            field=jsonfield.fields.JSONField(blank=True, null=True, verbose_name='List of allowed claims. If None, all claims from allowed scopes are returned'),
        ),
        migrations.AddField(
            model_name='openidclient',
            name='allowed_scopes',
            field=jsonfield.fields.JSONField(blank=True, null=True, verbose_name='List of allowed scopes. If None, all scopes are allowed'),
        ),
    ]
